@@ -11,3 +11,7 @@ sed -i -r 's/(\[php\])/<?php/' $FILE
 # convert markdown to reStructured Text
 pandoc -f markdown -t rst $FILE > ${FILE%.md}.rst
 
+if [ -a ${FILE%.md}.md-r ] 
+  then
+    rm ${FILE%.md}.md-r
+fi
